;;
;; This is a cushion module to use R7RS (scheme repl) from Gauche
;;
(define-module scheme.repl (use r7rs-setup))
